# Generated by Django 2.2.10 on 2020-02-27 21:51

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0019_eveasset'),
    ]

    operations = [
        migrations.RenameField(
            model_name='eveasset',
            old_name='item',
            new_name='item_name',
        ),
        migrations.AddField(
            model_name='eveasset',
            name='category_id',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='eveasset',
            name='group_id',
            field=models.IntegerField(default=0),
            preserve_default=False,
        ),
    ]
