# Generated by Django 2.2.13 on 2020-09-20 21:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0026_auto_20200309_1419'),
    ]

    operations = [
        migrations.AddField(
            model_name='evescope',
            name='required',
            field=models.BooleanField(default=True),
        ),
        migrations.DeleteModel(
            name='EveTokenType',
        ),
    ]
