<table class="table table-striped">
  <thead>
    <tr>
      <th>Portrait</th>
      <th>Character Name</th>
      <th>Affiliation</th>
    </tr>
  </thead>
  <tbody>
  {% for token in application.request_user.eve_tokens.all %}
    <tr>
      <td>
          <img style="width: 50px;" src="https://imageserver.eveonline.com/Character/{{token.evecharacter.external_id}}_128.jpg"/>
      </td>
      <td>
          <a href="{% url 'django-eveonline-connector-view-character' token.evecharacter.external_id %}">{{token.evecharacter.name}}</a>
      </td>
      <td>
      {% if token.evecharacter.corporation.alliance %}
      <img style="width: 50px;" src="https://images.evetech.net/alliances/{{token.evecharacter.corporation.alliance.external_id}}/logo/"/>
      <i> {{token.evecharacter.corporation.alliance.name}}</i>
      {% else %}
      <img style="width: 50px;" src="https://images.evetech.net/corporations/{{token.evecharacter.corporation.external_id}}/logo/"/>
      <i class="hidden-xs"> {{token.evecharacter.corporation.name}}</i>
      {% endif %}
      </td>
    </tr>
  {% endfor %}
  <!-- Bottom Divider -->
  </tbody>
</table>