# Generated by Django 2.2.10 on 2020-03-03 18:41

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0021_auto_20200227_2343'),
    ]

    operations = [
        migrations.RenameModel(
            old_name='EveClone',
            new_name='EveJumpClone',
        ),
    ]
