# Generated by Django 2.2.4 on 2019-09-03 20:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='evetoken',
            name='primary',
            field=models.BooleanField(default=False),
        ),
    ]
