# Generated by Django 2.2.10 on 2020-02-27 18:21

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0017_primaryevecharacterassociation'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='evetoken',
            name='primary',
        ),
    ]
