# Generated by Django 2.2.10 on 2020-03-09 14:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0025_auto_20200308_2220'),
    ]

    operations = [
        migrations.RenameField(
            model_name='evetransaction',
            old_name='type_name',
            new_name='item_name',
        ),
    ]
