# Generated by Django 2.2.10 on 2020-02-27 18:14

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('django_eveonline_connector', '0016_auto_20200226_1730'),
    ]

    operations = [
        migrations.CreateModel(
            name='PrimaryEveCharacterAssociation',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('character', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='primary_to', to='django_eveonline_connector.EveCharacter')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='primary_evecharacter', to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
