
<table class="table table-bordered table-hover">
    <thead>
        <tr>

            <th>Character</th>
            <th class="text-center">Actions</th>
        </tr>
    </thead>
    <tbody>
        {% for token in request.user.eve_tokens.all %}
        <tr>

            <td class="col-lg-6 col-xs-6">
                <div class="pull-left" style="padding-right: 8px;">
                    <img width="36px" style="text-align: center; border: 3px solid #000; padding: 0;"
                        src="https://imageserver.eveonline.com/Character/{{token.evecharacter.external_id}}_64.jpg" />
                </div>
                <div>
                    {% if 'django_eveonline_connector' not in INSTALLED_APPS %}
                    <b class="hidden-xs">{{token.evecharacter.name}}</b>
                    {% else %}
                    <b class="hidden-xs"><a href="{% url 'django-eveonline-connector-view-character' token.evecharacter.external_id %}">{{token.evecharacter.name}}</a></b>
                    {% endif %}
                    <br>
                    {% if token.evecharacter.corporation %}
                    <i class="hidden-xs">{{token.evecharacter.corporation.name}}</i>
                    {% else %}
                    <i class="hidden-xs">Unknown Corporation</i>
                    {% endif %}
                </div>
            </td>

            <td class="col-lg-6 col-xs-6">
                <div style="display: flex;" class="btn-group btn-block">
                    {% if token.valid %}
                    <a href="{% url 'django-eveonline-connector-character-refresh-public' token.evecharacter.external_id %}" style="flex: 1" class="btn btn-success"><i class="fa fa-refresh"></i></a>
                    <a href="{% url 'django-eveonline-connector-sso-token-remove' token.pk %}" style="flex: 1" class="btn btn-danger"><i class="fa fa-times"></i></a>
                    {% else %}
                    <a href="{% url 'django-eveonline-connector-sso-token-update' token.pk %}" style="flex: 1" class="btn btn-warning">Update Token</a>
                    {% endif %}
                </div>
            </td>
        </tr>
        {% endfor %}
        <!-- Bottom Divider -->
        
    </tbody>
</table>