# Generated by Django 2.2.10 on 2020-02-25 21:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0012_auto_20200225_1921'),
    ]

    operations = [
        migrations.AddField(
            model_name='evetokentype',
            name='description',
            field=models.CharField(default='Empty', max_length=64),
            preserve_default=False,
        ),
    ]
