# Generated by Django 2.2.10 on 2020-09-28 16:20

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0030_auto_20200928_0013'),
    ]

    operations = [
        migrations.CreateModel(
            name='EveCharacterInfo',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('skill_points', models.IntegerField(blank=True, null=True)),
                ('net_worth', models.FloatField(blank=True, null=True)),
                ('assets_last_updated', models.DateTimeField(blank=True, null=True)),
                ('jump_clones_last_updated', models.DateTimeField(blank=True, null=True)),
                ('contacts_last_updated', models.DateTimeField(blank=True, null=True)),
                ('contracts_last_updated', models.DateTimeField(blank=True, null=True)),
                ('skills_last_updated', models.DateTimeField(blank=True, null=True)),
                ('journal_last_updated', models.DateTimeField(blank=True, null=True)),
                ('transactions_last_updated', models.DateTimeField(blank=True, null=True)),
                ('character', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='info', to='django_eveonline_connector.EveCharacter')),
            ],
        ),
    ]
