# Generated by Django 2.2.4 on 2019-10-03 20:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0005_auto_20191003_1947'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='evetoken',
            unique_together=set(),
        ),
    ]
