# Generated by Django 2.2.10 on 2020-03-08 22:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0024_auto_20200308_2049'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evecontact',
            name='label_ids',
            field=models.TextField(blank=True, null=True),
        ),
    ]
