# Generated by Django 2.2.8 on 2019-12-11 15:14

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0009_auto_20191210_1538'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evecharacter',
            name='token',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.CASCADE, to='django_eveonline_connector.EveToken'),
        ),
    ]
