# Generated by Django 2.2.10 on 2020-09-30 18:05

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0032_auto_20200929_1545'),
    ]

    operations = [
        migrations.AddField(
            model_name='evecorporation',
            name='track_characters',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='evecorporation',
            name='track_corporation',
            field=models.BooleanField(default=False),
        ),
    ]
