# Generated by Django 2.2.10 on 2020-02-26 17:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0015_merge_20200226_1503'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='eveclient',
            options={'verbose_name': 'Eve Settings', 'verbose_name_plural': 'Eve Settings'},
        ),
    ]
