# Generated by Django 2.2.10 on 2020-02-25 19:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0011_auto_20191211_1624'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='eveclient',
            name='esi_sso_url',
        ),
        migrations.CreateModel(
            name='EveTokenType',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=32, unique=True)),
                ('esi_sso_url', models.URLField(editable=False, max_length=2056)),
                ('scopes', models.ManyToManyField(blank=True, to='django_eveonline_connector.EveScope')),
            ],
        ),
    ]
