# Generated by Django 2.2.13 on 2020-10-04 01:30

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0034_evestructure'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evecontract',
            name='items',
            field=models.TextField(null=True),
        ),
    ]
