# Generated by Django 2.2.13 on 2020-10-25 18:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0037_auto_20201018_1628'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evestructure',
            name='fuel_expires',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='next_reinforce_apply',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='next_reinforce_hour',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='next_reinforce_weekday',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='reinforce_weekday',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='services',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='state_timer_end',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='state_timer_start',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='type_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evestructure',
            name='unanchors_at',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
