# Generated by Django 2.2.13 on 2020-09-20 22:02

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0027_auto_20200920_2150'),
    ]

    operations = [
        migrations.AlterField(
            model_name='evescope',
            name='required',
            field=models.BooleanField(default=False),
        ),
    ]
