# Generated by Django 2.2.4 on 2019-10-03 19:47

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0004_remove_eveclient_esi_scopes'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='eveentity',
            name='portrait',
        ),
        migrations.RemoveField(
            model_name='evetoken',
            name='character',
        ),
        migrations.AddField(
            model_name='evecharacter',
            name='token',
            field=models.OneToOneField(null=True, on_delete=django.db.models.deletion.SET_NULL, to='django_eveonline_connector.EveToken'),
        ),
        migrations.AlterField(
            model_name='evetoken',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='eve_tokens', to=settings.AUTH_USER_MODEL),
        ),
        migrations.DeleteModel(
            name='EveWalletTransaction',
        ),
    ]
