# Generated by Django 2.2.4 on 2019-10-02 18:43

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0003_auto_20190903_2005'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='eveclient',
            name='esi_scopes',
        ),
    ]
