# Generated by Django 2.2.10 on 2020-02-27 19:07

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0018_remove_evetoken_primary'),
    ]

    operations = [
        migrations.CreateModel(
            name='EveAsset',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('is_blueprint_copy', models.BooleanField()),
                ('is_singleton', models.BooleanField()),
                ('item_id', models.IntegerField()),
                ('location_flag', models.CharField(max_length=64)),
                ('location_id', models.IntegerField()),
                ('location_type', models.CharField(max_length=64)),
                ('type_id', models.IntegerField()),
                ('item', models.CharField(max_length=128)),
                ('item_type', models.CharField(max_length=32)),
                ('location', models.CharField(max_length=128)),
                ('quantity', models.IntegerField()),
                ('entity', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='assets', to='django_eveonline_connector.EveEntity')),
            ],
        ),
    ]
