# Generated by Django 2.2.10 on 2020-02-26 15:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0013_evetokentype_description'),
        ('django_eveonline_connector', '0014_load_intial_data'),
    ]

    operations = [
    ]
