{% extends "django_eveonline_connector/adminlte/characters/view_character.html" %}

{% block header %}
Clones
{% endblock %}

{% block description %}
{{character.name}}
{% endblock %}

{% block tab_content %}
<div class="box box-info box-solid">
    <div class="box-header">
        <h3>Jump Clone List</h3>
    </div>
    <div class="box-body">
        <table class="datatable table table-bordered table-hover text-center">
            <thead>
                <th class="col-lg-4 col-md-4 col-xs-2">Location</th>
                <th class="col-lg-4 col-md-4 col-xs-2">Implants</th>
            </thead>
            <tbody>
            </tbody>
        </table>
    </div>
</div>

{% endblock %}

{% block scripts %}
<script>
    $.fn.DataTable.ext.pager.numbers_length = 5;
    $(function () {
        $('table').DataTable({
            'paging': true,
            'lengthChange': true,
            'searching': true,
            'ordering': true,
            'order': [[1, 'asc']],
            'pageLength': 5,
            "autoWidth": false,
            'serverSide': true,
            "ajax": "{% url 'django-eveonline-connector-api-clones' %}?external_id={{character.external_id}}"
        })
    })
</script>
<script>
    $(document).ready(function () {
        $('#clones').addClass('active');
    });
</script>

{% endblock %}