# Generated by Django 2.2.10 on 2020-03-08 20:49

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0023_evecontact_evecontract_evejournalentry_eveskill_evetransaction'),
    ]

    operations = [
        migrations.RenameField(
            model_name='eveasset',
            old_name='location',
            new_name='location_name',
        ),
    ]
