# Generated by Django 2.2.10 on 2020-09-29 15:45

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_eveonline_connector', '0031_evecharacterinfo'),
    ]

    operations = [
        migrations.AlterField(
            model_name='eveasset',
            name='item_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='eveasset',
            name='location_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='evecontract',
            name='end_location_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evecontract',
            name='start_location_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evejournalentry',
            name='context_id',
            field=models.BigIntegerField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='evejournalentry',
            name='external_id',
            field=models.BigIntegerField(unique=True),
        ),
        migrations.AlterField(
            model_name='evejumpclone',
            name='location_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='evetransaction',
            name='journal_ref_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='evetransaction',
            name='location_id',
            field=models.BigIntegerField(),
        ),
        migrations.AlterField(
            model_name='evetransaction',
            name='transaction_id',
            field=models.BigIntegerField(unique=True),
        ),
    ]
