<li class="treeview">
    <a href="#">
        <i class="fa fa-search"></i> <span>EVE Online</span>
        <span class="pull-right-container">
            <i class="fa fa-angle-left pull-right"></i>
        </span>
    </a>
    
    <ul class="treeview-menu">
        {% if perms.django_eveonline_connector.view_evecharacter %}
        <li><a href="{% url 'django-eveonline-connector-characters-view' %}"><i class="fa fa-user"></i>Characters</a></li>
        {% endif %}
        {% if perms.django_eveonline_connector.view_evecorporation %}
        <li><a href="{% url 'django-eveonline-connector-corporations-view' %}"><i class="fa fa-building-o"></i>Corporations</a></li>
        {% endif %}
    </ul>
    
</li>
